<?php

namespace Litecms\BusLists\Providers;

use Illuminate\Support\ServiceProvider;

class BusListsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'bus_lists');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'bus_lists');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.bus_lists', function ($app) {
            return $this->app->make('Litecms\BusLists\BusLists');
        });

                // Bind BusLists to repository
        $this->app->bind(
            'Litecms\BusLists\Interfaces\BusListsRepositoryInterface',
            \Litecms\BusLists\Repositories\Eloquent\BusListsRepository::class
        );

        $this->app->register(\Litecms\BusLists\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\BusLists\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\BusLists\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.bus_lists'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/bus_lists.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/bus_lists')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/bus_lists')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
